diff libinterp/corefcn/quadcc.cc @ 25172:7b1b504c2f12 stable

update future version numbers in doc strings and comments * NEWS, octave-dock-widget.cc, graphics.in.h, gripes.cc, gripes.h, oct-obj.h, oct.h, quadcc.cc, utils.cc, options-usage.h, lo-array-gripes.cc, lo-array-gripes.h, bitmax.m, chop.m, desktop.m, java2mat.m, mahalanobis.m, md5sum.m, octave_config_info.m, onenormest.m, sleep.m, tmpnam.m, toascii.m, usleep.m, wavread.m, wavwrite.m, annotation.m, __gnuplot_draw_axes__.m, deprecate-props.tst: Refer to future versions as versions 5 and 6, not 4.5+, 4.6, 4.7+, or 4.8.
author John W. Eaton <jwe@octave.org>
date Mon, 09 Apr 2018 07:54:15 -0400
parents 6652d3823428
children 00f796120a6d
line wrap: on
line diff
--- a/libinterp/corefcn/quadcc.cc	Mon Apr 09 07:18:32 2018 -0400
+++ b/libinterp/corefcn/quadcc.cc	Mon Apr 09 07:54:15 2018 -0400
@@ -1551,10 +1551,10 @@
 successive interpolations of the integrand over the nodes of the respective
 quadrature rules.
 
-@c FIXME: Remove in Octave version 4.8
+@c FIXME: DEPRECATED: Remove in Octave version 6.
 Implementation Note: For Octave versions @leq{} 4.2, @code{quadcc} accepted a
 single tolerance argument which specified the relative tolerance.  For
-versions 4.4 and 4.6, @code{quadcc} will issue a warning when called with a
+versions 4.4 and 5, @code{quadcc} will issue a warning when called with a
 single tolerance argument indicating that the meaning of this input has
 changed from relative tolerance to absolute tolerance.  The warning ID for this
 message is @qcode{"Octave:quadcc:RelTol-conversion"}.  The warning may be
@@ -1647,7 +1647,7 @@
 
       if (tol.numel () == 1)
         {
           // FIXME: Remove warning in Octave version 4.8
           static bool do_warn = true;
           if (do_warn)
             {
@@ -1647,7 +1647,7 @@
       if (tol.numel () == 1)
         {
-          // FIXME: Remove warning in Octave version 4.8
+          // FIXME: DEPRECATED: Remove warning in Octave version 6.
           static bool do_warn = true;
           if (do_warn)